@@ -12,7 +12,7 @@ from trytond.wizard import Wizard, StateTransition, StateView, StateAction, \
     Button
 from trytond.report import Report
 from trytond import backend
-from trytond.pyson import Eval, Bool, PYSONEncoder
+from trytond.pyson import Eval, Bool, If, PYSONEncoder
 from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 from trytond.rpc import RPC
@@ -1345,9 +1345,12 @@ class Line(ModelSQL, ModelView):
             if not journal.view:
                 return result
 
+            colors = PYSONEncoder().encode(
+                If(Eval('state', '') == 'draft', 'red', 'black'))
+            # Use single quote for colors as pyson contains double quote
             xml = '<?xml version="1.0"?>\n' \
                 '<tree string="%s" editable="top" on_write="on_write" ' \
-                'colors="red:state==\'draft\'">\n' % title
+                'colors=\'%s\'>\n' % (title, colors)
             fields = set()
             for column in journal.view.columns:
                 fields.add(column.field.name)
