@@ -236,6 +236,15 @@ class TaxCode(ModelSQL, ModelView):
             (cls._rec_name,) + tuple(clause[1:]),
             ]
 
+    @classmethod
+    def copy(cls, codes, default=None):
+        if default is None:
+            default = {}
+        else:
+            default = default.copy()
+        default.setdefault('template')
+        return super(TaxCode, cls).copy(codes, default=default)
+
     @classmethod
     def delete(cls, codes):
         codes = cls.search([
@@ -738,6 +747,15 @@ class Tax(ModelSQL, ModelView):
             return self.company.currency.digits
         return 2
 
+    @classmethod
+    def copy(cls, taxes, default=None):
+        if default is None:
+            default = {}
+        else:
+            default = default.copy()
+        default.setdefault('template')
+        return super(Tax, cls).copy(taxes, default=default)
+
     def _process_tax(self, price_unit):
         if self.type == 'percentage':
             amount = price_unit * self.rate
@@ -1022,6 +1040,15 @@ class TaxRule(ModelSQL, ModelView):
     def default_kind():
         return 'both'
 
+    @classmethod
+    def copy(cls, rules, default=None):
+        if default is None:
+            default = {}
+        else:
+            default = default.copy()
+        default.setdefault('template')
+        return super(TaxRule, cls).copy(rules, default=default)
+
     def apply(self, tax, pattern):
         '''
         Apply rule on tax
@@ -1252,6 +1279,15 @@ class TaxRuleLine(ModelSQL, ModelView):
         table, _ = tables[None]
         return [table.sequence == None, table.sequence]
 
+    @classmethod
+    def copy(cls, lines, default=None):
+        if default is None:
+            default = {}
+        else:
+            default = default.copy()
+        default.setdefault('template')
+        return super(TaxRuleLine, cls).copy(lines, default=default)
+
     def match(self, pattern):
         '''
         Match line on pattern
